tokenizer\_tools.tagset.offset.analysis package
===============================================

Submodules
----------

tokenizer\_tools.tagset.offset.analysis.corpus\_pattern module
--------------------------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.analysis.corpus_pattern
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.offset.analysis.document\_pattern module
----------------------------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.analysis.document_pattern
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.offset.analysis.entity\_placeholder module
------------------------------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.analysis.entity_placeholder
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.offset.analysis.express\_pattern module
---------------------------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.analysis.express_pattern
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.offset.analysis.read\_markdown module
-------------------------------------------------------------

.. automodule:: tokenizer_tools.tagset.offset.analysis.read_markdown
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.tagset.offset.analysis
   :members:
   :undoc-members:
   :show-inheritance:
